@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2020-2021 Arnaud Rebillout
+ * Copyright (C) 2020-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -59,8 +59,8 @@ void          gv_streaminfo_unref(GvStreaminfo *self);
 
 gboolean gv_streaminfo_update_from_element_setup(GvStreaminfo *self,
 		                                 GstElement *element);
-gboolean gv_streaminfo_update_from_gst_audio_pad(GvStreaminfo *self,
-		                                 GstPad *audio_pad);
+gboolean gv_streaminfo_update_from_gst_caps     (GvStreaminfo *self,
+		                                 GstCaps *caps);
 gboolean gv_streaminfo_update_from_gst_taglist  (GvStreaminfo *self,
 		                                 GstTagList *taglist);
 
