@@ -46,11 +46,14 @@ static const gchar *translators =
 	"Benages <juanjo@benages.eu> - Spanish (es)\n"
 	"Gallegonovato <fran-carro@hotmail.es> - Spanish (es)\n"
 	"Holman Calderón <halecalderon@gmail.com> - Spanish (es)\n"
+	"Priit Jõerüüt <hwlate@joeruut.com> - Estonian (et)\n"
 	"Jiri Grönroos <jiri.gronroos@iki.fi> - Finnish (fi)\n"
+	"Ricky Tigg <ricky.tigg@gmail.com> - Finnish (fi)\n"
 	"Étienne Deparis <etienne@depar.is> - French (fr)\n"
 	"Jeannette L <j.lavoie@net-c.ca> - French (fr)\n"
 	"Milo Ivir <mail@milotype.de> - Croatian (hr)\n"
 	"Notramo <notramo@vipmail.hu> -  (hu)\n"
+	"Emilio S <emism.translations@gmail.com> - Interlingua (ia)\n"
 	"Reza Almanda <rezaalmanda27@gmail.com> - Indonesian (id)\n"
 	"Silvyaamalia <silvyaamalia@student.uns.ac.id> - Indonesian (id)\n"
 	"Albanobattistella <albano_battistella@hotmail.com> - Italian (it)\n"
@@ -72,6 +75,7 @@ static const gchar *translators =
 	"Иван <nkvdno@mail.ru> - Russian (ru)\n"
 	"Andrej Shadura <andrew@shadura.me> - Slovak (sk)\n"
 	"Marek Ľach <graweeld@googlemail.com> - Slovak (sk)\n"
+	"தமிழ்நேரம் <anishprabu.t@gmail.com> - Tamil (ta)\n"
 	"Akash Rao <akash.rao.ind@gmail.com> - Telugu (te)\n"
 	"Oğuz Ersen <oguz@ersen.moe> - Turkish (tr)\n"
 	"Oğuz Ersen <oguzersen@protonmail.com> - Turkish (tr)\n"
