@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2021 Arnaud Rebillout
+ * Copyright (C) 2015-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -33,12 +33,15 @@ G_DECLARE_FINAL_TYPE(GvStationDialog, gv_station_dialog, GV, STATION_DIALOG, Gtk
 
 /* Convenience functions */
 
-GvStation *gv_show_add_station_dialog (GtkWindow *parent);
-void       gv_show_edit_station_dialog(GtkWindow *parent, GvStation *station);
+GtkWidget *gv_make_add_station_dialog (GtkWindow *parent, GvStation *anchor);
+GtkWidget *gv_make_edit_station_dialog(GtkWindow *parent, GvStation *station);
 
 /* Methods */
 
-GtkWidget *gv_station_dialog_new     (GvStation *station);
-void       gv_station_dialog_fill_uri(GvStationDialog *dialog, const gchar *uri);
-void       gv_station_dialog_retrieve(GvStationDialog *self, GvStation *station);
+GtkWidget *gv_station_dialog_new     (GvStation *station, GvStation *anchor);
+void       gv_station_dialog_apply   (GvStationDialog *self);
 GvStation *gv_station_dialog_create  (GvStationDialog *self);
+
+/* Property accessors */
+
+GvStation *gv_station_dialog_get_anchor(GvStationDialog *self);
