@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2021 Arnaud Rebillout
+ * Copyright (C) 2015-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -750,7 +750,7 @@ gv_stations_tree_view_class_init(GvStationsTreeViewClass *class)
 
 	/* Signals */
 	signals[SIGNAL_POPULATED] =
-		g_signal_new("populated", G_TYPE_FROM_CLASS(class),
+		g_signal_new("populated", G_OBJECT_CLASS_TYPE(class),
 			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
 			     G_TYPE_NONE, 0);
 }
