@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2021 Arnaud Rebillout
+ * Copyright (C) 2015-2024 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-only
  *
@@ -53,7 +53,7 @@ GvMainWindowManager *gv_ui_main_window_manager;
 static GList *ui_objects;
 
 /*
- * Underlying graphical toolkit
+ * Graphical toolkit
  */
 
 GOptionGroup *
@@ -69,22 +69,21 @@ gv_ui_toolkit_init_get_option_group(void)
 	return gtk_get_option_group(FALSE);
 }
 
-const gchar *
-gv_ui_toolkit_runtime_version_string(void)
-{
-	return gtk_get_runtime_version_string();
-}
-
-const gchar *
-gv_ui_toolkit_compile_version_string(void)
-{
-	return gtk_get_compile_version_string();
-}
-
 /*
  * Ui public functions
  */
 
+const gchar *
+gv_ui_gtk_version_string(void)
+{
+	static gchar *text;
+
+	if (text == NULL)
+		text = g_strdup_printf("GTK %u.%u.%u", gtk_get_major_version(),
+				gtk_get_minor_version(), gtk_get_micro_version());
+
+	return text;
+}
 void
 gv_ui_hide(void)
 {
@@ -99,8 +98,8 @@ void
 gv_ui_present_about(void)
 {
 	gv_show_about_dialog(GTK_WINDOW(gv_ui_main_window),
-			     gv_core_audio_backend_runtime_version_string(),
-			     gv_ui_toolkit_runtime_version_string());
+			     gv_core_gst_version_string(),
+			     gv_ui_gtk_version_string());
 }
 
 void
@@ -128,15 +127,38 @@ gv_ui_present_main(void)
 	gtk_window_present(GTK_WINDOW(gv_ui_main_window));
 }
 
-void
-gv_ui_present_add_station(void)
+static void
+on_add_station_dialog_response(GtkWidget* dialog,
+		gint response_id,
+		GtkWindow *parent G_GNUC_UNUSED)
 {
+	GvStationDialog *station_dialog = GV_STATION_DIALOG(dialog);
 	GvStationList *station_list = gv_core_station_list;
 	GvStation *station;
 
-	station = gv_show_add_station_dialog(GTK_WINDOW(gv_ui_main_window));
-	if (station)
-		gv_station_list_append(station_list, station);
+	if (response_id != GTK_RESPONSE_OK)
+		goto out;
+
+	station = gv_station_dialog_create(station_dialog);
+	if (station == NULL)
+		goto out;
+
+	gv_station_list_append(station_list, station);
+
+out:
+	gtk_widget_destroy(dialog);
+}
+
+void
+gv_ui_present_add_station(void)
+{
+	GtkWindow *parent = GTK_WINDOW(gv_ui_main_window);
+	GtkWidget *dialog;
+
+	dialog = gv_make_add_station_dialog(parent, NULL);
+	g_signal_connect_object(dialog, "response",
+			G_CALLBACK(on_add_station_dialog_response), parent, 0);
+	gtk_widget_show(dialog);
 }
 
 void
